@@ -1,5 +1,14 @@
 //! Include many files in your Rust code for self-contained binaries.
 //!
+//! **Highlights**:
+//!
+//! - Include or exclude files with **path patterns**.
+//! - File lookups **checked** at compile time are **fast** at runtime (constant
+//!   time).
+//! - **Customizable**: associate any data with files.
+//! - Many [**examples**](https://github.com/evolutics/iftree/tree/main/examples).
+//! - See also [**related projects**](#related-work).
+//!
 //! ![Test](https://github.com/evolutics/iftree/actions/workflows/test.yml/badge.svg)
 //! [![crates.io](https://img.shields.io/crates/v/iftree.svg)](https://crates.io/crates/iftree)
 //!
@@ -25,15 +34,12 @@
 //! Iftree:    any_macro!("my_files/**")
 //! ```
 //!
-//! Refer to [**related work**](#related-work) to see Iftree in the context of
-//! other, similar projects.
-//!
 //! # Introduction
 //!
 //! Here is a minimal example that shows the basic functionality.
 //!
 //! ```ignore
-//! // Say you have the following files:
+//! // Say you have these files:
 //! //
 //! //     my_assets/
 //! //     ├── file_a
@@ -41,8 +47,7 @@
 //! //     └── folder/
 //! //         └── file_c
 //!
-//! // To include these files in your code, the macro `iftree::include_file_tree` is
-//! // attached to a custom type like this:
+//! // To include this file tree in your code, define a custom type like so:
 //! #[iftree::include_file_tree("paths = '/my_assets/**'")]
 //! pub struct MyAsset {
 //!     contents_str: &'static str,
@@ -53,8 +58,7 @@
 //! // `include_str!`, but you can plug in your own initializer.
 //!
 //! fn main() {
-//!     // Based on this, Iftree generates an array `ASSETS` with the desired file
-//!     // data. You can use it like so:
+//!     // Based on this, an array `ASSETS` with the desired file data is generated:
 //!     assert_eq!(ASSETS.len(), 3);
 //!     assert_eq!(ASSETS[0].contents_str, "… contents file_a\n");
 //!     assert_eq!(ASSETS[1].contents_str, "… contents file_b\n");
@@ -76,31 +80,55 @@
 //!
 //! 1. Add the **dependency** `iftree = "1.0"` to your manifest (`Cargo.toml`).
 //!
-//! 1. Define your **asset type** (`MyAsset` in the [introduction](#introduction)).
+//! 1. Define your **asset type**, which is just a custom `struct` or type alias.
+//!    Example:
 //!
-//!    This is a `struct` with the fields you need per file. Alternatively, it can
-//!    be a type alias, which may be convenient if you have exactly one field.
+//!    ```rust
+//!    pub struct Asset;
+//!    ```
 //!
-//! 1. Next, **filter files** to be included by annotating your asset type with
-//!    `#[iftree::include_file_tree("paths = '/my/assets/**'")]`.
+//! 1. Next, **filter files** to be included by annotating your asset type. Example:
+//!
+//!    ```ignore
+//!    #[iftree::include_file_tree("paths = '/my_assets/**'")]
+//!    pub struct Asset;
+//!    ```
 //!
 //!    The macro argument is a [TOML](https://toml.io) string literal. Its `paths`
 //!    option here supports `.gitignore`-like path patterns, with one pattern per
 //!    line. These paths are relative to the folder with your manifest by default.
 //!    See the [`paths` configuration](#paths) for more.
 //!
-//! 1. When building your project, code is generated that uses an **initializer** to
+//! 1. Define the **data fields** of your asset type. Example:
+//!
+//!    ```ignore
+//!    #[iftree::include_file_tree("paths = '/my_assets/**'")]
+//!    pub struct Asset {
+//!        relative_path: &'static str,
+//!        contents_bytes: &'static [u8],
+//!    }
+//!    ```
+//!
+//!    When building your project, code is generated that uses an initializer to
 //!    instantiate the asset type once per file.
 //!
-//!    By default, a field `contents_str` (if any) is populated with `include_str!`,
-//!    a field `contents_bytes` is populated with `include_bytes!`, and a couple of
-//!    other [standard fields](#standard-fields) are recognized. However, you can
-//!    plug in your own macro to fully customize the initialization by
+//!    By default, a field `contents_bytes` (if any) is populated with the file
+//!    contents as a byte array, a field `contents_str` is populated with the file
+//!    contents as a string, and a couple of other
+//!    [standard fields](#standard-fields) are recognized.
+//!
+//!    However, you can fully customize the initialization by
 //!    [configuring an initializer](#templateinitializer). For even more control
 //!    over code generation, there is the concept of [visitors](#template-visitors).
 //!
 //! 1. Now you can **access** your included file data via `ASSETS` array or via
-//!    `base::my::assets::MY_FILE` variables.
+//!    `base::x::y::MY_FILE` variables. Example:
+//!
+//!    ```ignore
+//!    println!("Number of assets: {}", ASSETS.len());
+//!    assert_eq!(base::my_assets::MY_FILE.relative_path, "my_assets/my_file");
+//!    assert_eq!(base::my_assets::MY_FILE.contents_bytes, b"file contents");
+//!    ```
 //!
 //! ## Examples
 //!
@@ -122,17 +150,17 @@
 //! asset type is generated without further configuration. You can still override
 //! these field names with a [custom initializer](#templateinitializer).
 //!
-//! - **`contents_bytes:`** `&'static [u8]`
+//! - **`contents_bytes`**: `&'static [u8]`
 //!
 //!   File contents as a byte array, using
 //!   [`std::include_bytes`](https://doc.rust-lang.org/std/macro.include_bytes.html).
 //!
-//! - **`contents_str:`** `&'static str`
+//! - **`contents_str`**: `&'static str`
 //!
 //!   File contents interpreted as a UTF-8 string, using
 //!   [`std::include_str`](https://doc.rust-lang.org/std/macro.include_str.html).
 //!
-//! - **`get_bytes:`** `fn() -> std::borrow::Cow<'static, [u8]>`
+//! - **`get_bytes`**: `fn() -> std::borrow::Cow<'static, [u8]>`
 //!
 //!   In debug builds (that is, when
 //!   [`debug_assertions`](https://doc.rust-lang.org/reference/conditional-compilation.html#debug_assertions)
@@ -146,13 +174,13 @@
 //!   using
 //!   [`std::include_bytes`](https://doc.rust-lang.org/std/macro.include_bytes.html).
 //!
-//! - **`get_str:`** `fn() -> std::borrow::Cow<'static, str>`
+//! - **`get_str`**: `fn() -> std::borrow::Cow<'static, str>`
 //!
 //!   Same as `get_bytes` but for the file contents interpreted as a UTF-8 string,
 //!   using
 //!   [`std::include_str`](https://doc.rust-lang.org/std/macro.include_str.html).
 //!
-//! - **`relative_path:`** `&'static str`
+//! - **`relative_path`**: `&'static str`
 //!
 //!   File path relative to the base folder, which is the folder with your manifest
 //!   (`Cargo.toml`) by default. Path components are separated by a slash `/`,
@@ -166,9 +194,10 @@
 //! When generating identifiers based on paths, names are sanitized. For example, a
 //! filename `404_not_found.md` is sanitized to an identifier `_404_NOT_FOUND_MD`.
 //!
-//! The sanitization process is designed to generate valid
-//! [Unicode identifiers](https://doc.rust-lang.org/nightly/reference/identifiers.html).
-//! Essentially, it replaces invalid identifier characters by underscores `"_"`.
+//! The sanitization process is designed to generate valid, conventional
+//! [Unicode identifiers](https://doc.rust-lang.org/reference/identifiers.html).
+//! Essentially, it replaces invalid identifier characters by underscores `"_"` and
+//! adjusts the letter case to the context.
 //!
 //! More precisely, these transformations are applied in order:
 //!
@@ -217,6 +246,7 @@
 //!
 //! - Compression with [`include_flate`](https://github.com/evolutics/iftree/blob/main/examples/library_include_flate.rs)
 //! - File server with [Actix Web](https://github.com/evolutics/iftree/blob/main/examples/library_actix_web.rs)
+//! - File server with [Rocket](https://github.com/evolutics/iftree/blob/main/examples/library_rocket.rs)
 //! - File server with [Tide](https://github.com/evolutics/iftree/blob/main/examples/library_tide.rs)
 //! - File server with [warp](https://github.com/evolutics/iftree/blob/main/examples/library_warp.rs)
 //! - Lazy initialization with [`lazy_static`](https://github.com/evolutics/iftree/blob/main/examples/library_lazy_static.rs)
@@ -244,14 +274,14 @@
 //!
 //! Here is how I think Iftree compares to related projects for the given criteria.
 //!
-//! | Project                                                                            | File selection                                      | Included file data     | Data access via                                                                                     |
-//! | ---------------------------------------------------------------------------------- | --------------------------------------------------- | ---------------------- | --------------------------------------------------------------------------------------------------- |
-//! | [**`include_dir`**](https://github.com/Michael-F-Bryan/include_dir) 0.6            | Single folder                                       | Path, contents         | File path, nested iterators, glob patterns                                                          |
-//! | [**`includedir`**](https://github.com/tilpner/includedir) 0.6                      | Multiple files, multiple folders                    | Path, contents         | File path, iterator                                                                                 |
-//! | [**Rust Embed**](https://github.com/pyros2097/rust-embed) 5.9                      | Single folder                                       | Path, contents         | File path, iterator                                                                                 |
-//! | [**`std::include_bytes`**](https://doc.rust-lang.org/std/macro.include_bytes.html) | Single file                                         | Contents               | File path                                                                                           |
-//! | [**`std::include_str`**](https://doc.rust-lang.org/std/macro.include_str.html)     | Single file                                         | Contents               | File path                                                                                           |
-//! | **Iftree**                                                                         | Multiple files by inclusion-exclusion path patterns | Path, contents, custom | File path (via `base::x::y::MY_FILE` variables in constant time), iterator (`ASSETS` array), custom |
+//! | Project                                                                            | File selection                                      | Included file data       | Data access via                                                                                     |
+//! | ---------------------------------------------------------------------------------- | --------------------------------------------------- | ------------------------ | --------------------------------------------------------------------------------------------------- |
+//! | [**`include_dir`**](https://github.com/Michael-F-Bryan/include_dir) 0.6            | Single folder                                       | Path, contents           | File path, nested iterators, glob patterns                                                          |
+//! | [**`includedir`**](https://github.com/tilpner/includedir) 0.6                      | Multiple files, multiple folders                    | Path, contents           | File path, iterator                                                                                 |
+//! | [**Rust Embed**](https://github.com/pyros2097/rust-embed) 6.0                      | Single folder                                       | Path, contents, metadata | File path, iterator                                                                                 |
+//! | [**`std::include_bytes`**](https://doc.rust-lang.org/std/macro.include_bytes.html) | Single file                                         | Contents                 | File path                                                                                           |
+//! | [**`std::include_str`**](https://doc.rust-lang.org/std/macro.include_str.html)     | Single file                                         | Contents                 | File path                                                                                           |
+//! | **Iftree**                                                                         | Multiple files by inclusion-exclusion path patterns | Path, contents, custom   | File path (via `base::x::y::MY_FILE` variables in constant time), iterator (`ASSETS` array), custom |
 //!
 //! Generally, while Iftree has defaults to address common use cases, it can be
 //! customized to support more specific use cases, too (see [recipes](#recipes) for
@@ -270,7 +300,7 @@
 //! environment variable `CARGO_MANIFEST_DIR`. That is, a relative path `x/y/z` has
 //! a full path `[CARGO_MANIFEST_DIR]/[base_folder]/x/y/z`.
 //!
-//! **Default:** `""`
+//! **Default**: `""`
 //!
 //! See
 //! [example](https://github.com/evolutics/iftree/blob/main/examples/configuration_base_folder.rs).
@@ -280,7 +310,7 @@
 //! Whether to generate a string variable `DEBUG` with debug information such as the
 //! generated code.
 //!
-//! **Default:** `false`
+//! **Default**: `false`
 //!
 //! See
 //! [example](https://github.com/evolutics/iftree/blob/main/examples/configuration_debug.rs).
@@ -319,7 +349,7 @@
 //!
 //! The value of the environment variable should be an absolute path.
 //!
-//! **Default:** `"CARGO_MANIFEST_DIR"`
+//! **Default**: `"CARGO_MANIFEST_DIR"`
 //!
 //! ## `template.identifiers`
 //!
@@ -339,7 +369,7 @@
 //! rename any affected paths (assuming you need the generated identifiers at all –
 //! otherwise, you can just disable this with `template.identifiers = false`).
 //!
-//! **Default:** `true`
+//! **Default**: `true`
 //!
 //! See
 //! [example](https://github.com/evolutics/iftree/blob/main/examples/configuration_template_identifiers.rs).
@@ -356,7 +386,7 @@
 //! As an output, the macro must return a
 //! [constant expression](https://doc.rust-lang.org/reference/const_eval.html#constant-expressions).
 //!
-//! **Default:** A default initializer is constructed by recognizing
+//! **Default**: A default initializer is constructed by recognizing
 //! [standard fields](#standard-fields).
 //!
 //! See
@@ -453,19 +483,13 @@ mod tests {
 
     #[test]
     fn readme_includes_manifest_description() {
-        let manifest = get_manifest();
-        let description = manifest["package"]["description"].as_str().unwrap();
-        let embedded_description = format!("\n\n{}\n\n", description);
+        let embedded_description = format!("\n\n{}\n\n", env!("CARGO_PKG_DESCRIPTION"));
 
         let actual = get_readme().contains(&embedded_description);
 
         assert!(actual);
     }
 
-    fn get_manifest() -> toml::Value {
-        include_str!("../Cargo.toml").parse().unwrap()
-    }
-
     fn get_readme() -> &'static str {
         include_str!("../README.md")
     }
@@ -481,19 +505,18 @@ mod tests {
 
     #[test]
     fn readme_refers_to_current_manifest_version() {
-        let version = get_manifest_version();
-        let major_minor_version = version.rsplitn(2, '.').nth(1).unwrap();
-        let dependency = format!("`iftree = \"{}\"`", major_minor_version);
+        let dependency = format!(
+            "`{} = \"{}.{}\"`",
+            env!("CARGO_PKG_NAME"),
+            env!("CARGO_PKG_VERSION_MAJOR"),
+            env!("CARGO_PKG_VERSION_MINOR"),
+        );
 
         let actual = get_readme().contains(&dependency);
 
         assert!(actual);
     }
 
-    fn get_manifest_version() -> String {
-        String::from(get_manifest()["package"]["version"].as_str().unwrap())
-    }
-
     #[test]
     fn readme_links_to_each_example_exactly_once() {
         let mut actual =
@@ -516,7 +539,7 @@ mod tests {
 
     #[test]
     fn changelog_contains_current_manifest_version() {
-        let version_section = format!("\n\n## {} – ", get_manifest_version());
+        let version_section = format!("\n\n## {} – ", env!("CARGO_PKG_VERSION"));
 
         let actual = get_changelog().contains(&version_section);
 
@@ -538,10 +561,8 @@ mod tests {
                     let line = line.strip_prefix(' ').unwrap_or(line);
                     let line = if is_empty && line.starts_with('#') {
                         format!("#{}", line)
-                    } else if line == "```ignore" {
-                        String::from("```rust")
                     } else {
-                        String::from(line)
+                        line.replace("```ignore", "```rust")
                     };
                     actual.push_str(&format!("{}\n", line));
                     is_empty = line.is_empty();
