@@ -1,11 +1,10 @@
 use crate::model;
 use std::path;
-use std::vec;
 
 pub fn main(
     base_folder: path::PathBuf,
-    paths: vec::Vec<path::PathBuf>,
-) -> model::Result<vec::Vec<model::Path>> {
+    paths: Vec<path::PathBuf>,
+) -> model::Result<Vec<model::Path>> {
     paths
         .into_iter()
         .map(|path| get_path(&base_folder, path))
@@ -13,12 +12,21 @@ pub fn main(
 }
 
 fn get_path(base_folder: &path::Path, path: path::PathBuf) -> model::Result<model::Path> {
-    let relative = get_path_string(path.strip_prefix(base_folder)?)?;
+    let relative = get_path_components(path.strip_prefix(base_folder)?)?;
     let absolute = get_path_string(&path)?;
 
     Ok(model::Path { relative, absolute })
 }
 
+fn get_path_components(path: &path::Path) -> model::Result<Vec<String>> {
+    path.iter()
+        .map(|component| match component.to_str() {
+            None => Err(model::Error::PathInvalidUnicode(path.to_path_buf())),
+            Some(string) => Ok(String::from(string)),
+        })
+        .collect()
+}
+
 fn get_path_string(path: &path::Path) -> model::Result<String> {
     match path.to_str() {
         None => Err(model::Error::PathInvalidUnicode(path.to_path_buf())),
@@ -43,11 +51,11 @@ mod tests {
         let actual = actual.unwrap();
         let expected = vec![
             model::Path {
-                relative: String::from('c'),
+                relative: vec![String::from('c')],
                 absolute: String::from("/a/b/c"),
             },
             model::Path {
-                relative: String::from("a/b"),
+                relative: vec![String::from('a'), String::from('b')],
                 absolute: String::from("/a/b/a/b"),
             },
         ];
